==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/NlpVerticalLimitSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Job execution constraints.
 * @property maxConcurrentTrials Maximum Concurrent AutoML iterations.
 * @property maxTrials Number of AutoML iterations.
 * @property timeout AutoML job timeout.
 */
public data class NlpVerticalLimitSettingsArgs(
    public val maxConcurrentTrials: Output<Int>? = null,
    public val maxTrials: Output<Int>? = null,
    public val timeout: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs.builder()
            .maxConcurrentTrials(maxConcurrentTrials?.applyValue({ args0 -> args0 }))
            .maxTrials(maxTrials?.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NlpVerticalLimitSettingsArgs].
 */
@PulumiTagMarker
public class NlpVerticalLimitSettingsArgsBuilder internal constructor() {
    private var maxConcurrentTrials: Output<Int>? = null

    private var maxTrials: Output<Int>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value Maximum Concurrent AutoML iterations.
     */
    @JvmName("xlxaqovnkltxpadl")
    public suspend fun maxConcurrentTrials(`value`: Output<Int>) {
        this.maxConcurrentTrials = value
    }

    /**
     * @param value Number of AutoML iterations.
     */
    @JvmName("gqbppurngeewbpgx")
    public suspend fun maxTrials(`value`: Output<Int>) {
        this.maxTrials = value
    }

    /**
     * @param value AutoML job timeout.
     */
    @JvmName("ckxtoddnbtxmqksm")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value Maximum Concurrent AutoML iterations.
     */
    @JvmName("udlxraaahlgnppfv")
    public suspend fun maxConcurrentTrials(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxConcurrentTrials = mapped
    }

    /**
     * @param value Number of AutoML iterations.
     */
    @JvmName("xootpnhrnxigeunh")
    public suspend fun maxTrials(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxTrials = mapped
    }

    /**
     * @param value AutoML job timeout.
     */
    @JvmName("ywxfpgxemnlwqybc")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): NlpVerticalLimitSettingsArgs = NlpVerticalLimitSettingsArgs(
        maxConcurrentTrials = maxConcurrentTrials,
        maxTrials = maxTrials,
        timeout = timeout,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/NlpVerticalLimitSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Job execution constraints.
 * @property maxConcurrentTrials Maximum Concurrent AutoML iterations.
 * @property maxTrials Number of AutoML iterations.
 * @property timeout AutoML job timeout.
 */
public data class NlpVerticalLimitSettingsArgs(
    public val maxConcurrentTrials: Output<Int>? = null,
    public val maxTrials: Output<Int>? = null,
    public val timeout: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.NlpVerticalLimitSettingsArgs.builder()
            .maxConcurrentTrials(maxConcurrentTrials?.applyValue({ args0 -> args0 }))
            .maxTrials(maxTrials?.applyValue({ args0 -> args0 }))
            .timeout(timeout?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NlpVerticalLimitSettingsArgs].
 */
@PulumiTagMarker
public class NlpVerticalLimitSettingsArgsBuilder internal constructor() {
    private var maxConcurrentTrials: Output<Int>? = null

    private var maxTrials: Output<Int>? = null

    private var timeout: Output<String>? = null

    /**
     * @param value Maximum Concurrent AutoML iterations.
     */
    @JvmName("qyvooxrtmwqejdca")
    public suspend fun maxConcurrentTrials(`value`: Output<Int>) {
        this.maxConcurrentTrials = value
    }

    /**
     * @param value Number of AutoML iterations.
     */
    @JvmName("okcmfnymigojigln")
    public suspend fun maxTrials(`value`: Output<Int>) {
        this.maxTrials = value
    }

    /**
     * @param value AutoML job timeout.
     */
    @JvmName("tqjemmwaohpntqnm")
    public suspend fun timeout(`value`: Output<String>) {
        this.timeout = value
    }

    /**
     * @param value Maximum Concurrent AutoML iterations.
     */
    @JvmName("hbtmfnvfhwrbcnhr")
    public suspend fun maxConcurrentTrials(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxConcurrentTrials = mapped
    }

    /**
     * @param value Number of AutoML iterations.
     */
    @JvmName("smioxnfxjbndukeb")
    public suspend fun maxTrials(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxTrials = mapped
    }

    /**
     * @param value AutoML job timeout.
     */
    @JvmName("kgjlkltmjwhnjdst")
    public suspend fun timeout(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    internal fun build(): NlpVerticalLimitSettingsArgs = NlpVerticalLimitSettingsArgs(
        maxConcurrentTrials = maxConcurrentTrials,
        maxTrials = maxTrials,
        timeout = timeout,
    )
}
